# Arithmetic Eval

`arithmeval` or `Arithmetic Eval` is a python package that lets you safely evaluate arithmetic expressions.

Quick start
-----------

1. Install using pip
   ```
   pip install arithmeval
   ```

2. ...